from distutils.core import setup

setup(
		name			= 'amod400_dist1',
		version			= '1.1.0',
		py_modules		= ['amod400_dist1'],
		author			= 'Phoenix',
		author_email	= 'mailme@gmail.com',
		url				= 'www.google.com',
		description		= 'test distribution from headsfirst',
	)